Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(22)

Unified Diff: third_party/WebKit/Source/modules/payments/PaymentsValidators.h

Issue 2410143003: Add currencySystem field to PaymentCurrencyAmount (Closed)
Patch Set: Add currencySystem field to PaymentCurrencyAmount Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/payments/PaymentsValidators.h
diff --git a/third_party/WebKit/Source/modules/payments/PaymentsValidators.h b/third_party/WebKit/Source/modules/payments/PaymentsValidators.h
index d7285141add312dc7f01d84c5bef63d7f25b5d68..70bca7ffecd1a23a8e7800b370bf66ca9e5a15ed 100644
--- a/third_party/WebKit/Source/modules/payments/PaymentsValidators.h
+++ b/third_party/WebKit/Source/modules/payments/PaymentsValidators.h
@@ -16,9 +16,12 @@ class MODULES_EXPORT PaymentsValidators final {
STATIC_ONLY(PaymentsValidators);
public:
// The most common identifiers are three-letter alphabetic codes as defined by [ISO4217] (for example, "USD" for US Dollars)
// however any string of at most 2048 characters is considered valid. Returns false if currency |code| is too long (greater than 2048).
static bool isValidCurrencyCodeFormat(const String& code,
+ const String& system,
String* optionalErrorMessage);
// Returns true if |amount| is a valid currency code as defined in ISO 20022 CurrencyAnd30Amount.
@@ -16,9 +16,12 @@ class MODULES_EXPORT PaymentsValidators final {
STATIC_ONLY(PaymentsValidators);
public:
- // The most common identifiers are three-letter alphabetic codes as defined by [ISO4217] (for example, "USD" for US Dollars)
- // however any string of at most 2048 characters is considered valid. Returns false if currency |code| is too long (greater than 2048).
+ // The most common identifiers are three-letter alphabetic codes as defined by [ISO4217] (for example, "USD" for US Dollars).
+ // |system| is a URL that indicates the currency system that the currency identifier belongs to. By default,
+ // the value is urn:iso:std:iso:4217 indicating that currency is defined by [[ISO4217]], however any string of at most 2048
+ // characters is considered valid in other currencySystem. Returns false if currency |code| is too long (greater than 2048).
static bool isValidCurrencyCodeFormat(const String& code,

Powered by Google App Engine
This is Rietveld 408576698